from biogeme import *
from headers import *
from loglikelihood import *
from statistics import *
# Parameters to be estimated
# Arguments:
#   1  Name for report. Typically, the same as the variable
#   2  Starting value
#   3  Lower bound
#   4  Upper bound
#   5  0: estimate the parameter, 1: keep it fixed
#
ASC_Aroad = Beta('ASC_Aroad',0,-100,100,0)
ASC_Broad = Beta('ASC_Broad',0,-100,100,1)
B_TIME = Beta('B_TIME',0,-100,100,0)
B_COST = Beta('B_COST',0,-100,100,0)


Aroad_TIME = DefineVariable('Aroad_TIME', atime)
Aroad_COST = DefineVariable('Aroad_COST', acost)
Broad_TIME = DefineVariable('Broad_TIME', btime)
Broad_COST = DefineVariable('Broad_COST', bcost)


V1 = ASC_Aroad + B_TIME * Aroad_TIME + B_COST * Aroad_COST
V2 = ASC_Broad + B_TIME * Broad_TIME + B_COST * Broad_COST

V = {1: V1,
     2: V2}
	 
# Associate the availability conditions with the alternatives
A_AV_SP =  DefineVariable('A_AV_SP',a_av  * (  SP   !=  0  ))
B_AV_SP =  DefineVariable('B_AV_SP',b_av  * (  SP   !=  0  ))

av = {1: A_AV_SP,
      2: B_AV_SP}

	  
	  

# The choice model is a logit, with availability conditions
logprob = bioLogLogit(V,av,choice) 

# Defines an itertor on the data
rowIterator('obsIter') 

# Define the likelihood function for the estimation
BIOGEME_OBJECT.ESTIMATE = Sum(logprob,'obsIter')

# Statistics

nullLoglikelihood(av,'obsIter')
choiceSet = [1,2]
cteLoglikelihood(choiceSet,choice,'obsIter')
availabilityStatistics(av,'obsIter')

BIOGEME_OBJECT.PARAMETERS['optimizationAlgorithm'] = "BIO"

BIOGEME_OBJECT.FORMULAS['Aroad utility'] = V1
BIOGEME_OBJECT.FORMULAS['Broad utility'] = V2